package VMOMI::ActionType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
